;
; FILE REQUEST.ASM 						
;								
; COPYRIGHT 1980, 1981, 1982, 1983 CONVERGENT TECHNOLOGIES,INC.	
; ALL RIGHTS RESERVED						
;								
; THIS PROGRAM IS FURNISHED UNDER A LICENSE RESTRICTING ITS USE	
; SOLELY FOR THE OPERATION OF A DESIGNATED COMPUTER FOR A	
; PARTICULAR PURPOSE,AND MAY NOT BE COPIED OR OTHERWISE USED	
; WITHOUT THE PRIOR WRITTEN CONSENT OF CONVERGENT TECHNOLOGIES,	
; INC.  TITLE TO AND OWNERSHIP OF THE PROGRAM, INCLUDING ITS	
; SOURCE CODE, SHALL AT ALL TIMES REMAIN IN CONVERGENT		
; TECHNOLOGIES.							
;								
;								
; NOTES FOR CHANGING THIS FILE 				
;								
; Please be aware that in the Convergent Assembly language	
; there are two types of comments,normal comments,(any text on	
; a line after a ; character, and a macro comment (' text ').
; It is not possible to comment out a macro by inserting a	
; ; in front of it.  You may comment out a macro by replacing	
; the percent sign in the call with a ;,or by precceding the	
; call with '.  This will cause the macro processor to	
; ignore any text up to and including the next ' or RETURN	
; (0Ah) character,whichever comes first.			
;								
; Macro calls must not be mixed.  In general,the invocation of	
; a macro causes an entry to be added to a table,and mixing	
; macro calls would result in scrambled tables.			
;
$INCLUDE (Request_MF.mdf)
;
; There are three macros which are used to define requests:
;     SysRequest, UsrRequest, and Request.
;
; SysRequest is used by Convergent Technologies to construct the
; tables in level 0 (Workstation CTOS requests).
;
; UsrRequest is utilized by users who have previously defined request
; codes in the range 0FFFEh..0FFFFh (or 32 to 1 in decimal).  We suggest
; that new request codes not be defined in this block.
;
; All other request codes are defined using the Request macro.
;
; These macros constructs a set of tables which are used
; by CTOS to route the request to the proper CPU and to the
; proper exchange within a CPU.  Other fields of the requests
; are used to implement the procedural interface.
; 
; Requests are divided into groups called levels.  The request
; level is defined as the high 4 bits of the request code.  There
; is one exception to this rule: user requests in the range 1..32
; (0FFE0h..0FFFFh) are treated as being in a special level 16 (10h)
; for the purposes of generating the tables.  In this file, use the
; UsrRequest macro to define requests in the 1..32 range.
;
; Convergent reserves request levels 0 to 0Bh (request codes 0 to
; 0BFFF) for system use.  User requests must be defined in levels
; 0Ch to 0Fh or in the special range of 0FFFFh to 0FFFEh.  Remember
; that requests which are in even levels have procedural
; interfaces and must have corresponding entries in RqLabl.asm
; All requests, regardless of level, must have corresponding
; entries in Routing.asm 
;
; Request codes must be	contiguous.  Dummy entries may be added
; to fill space.  The requestNumber field is used by the
; macro just to verify the contiguity of the requests.
;								
;								
' SysRequest  Request  UsrRequest MACRO DEFINITION 		
'								
' MACRO FORMAT 						
'	These macros all take 8 arguments which are		
' described below.  The first 7 arguments must be on the same	
' line, and the last argument, the parameter format, can be on	
' additional lines.  A full description of the fields of the	
' macro and their use can be found in the CTOS manual and in	
' the System Programmers Guide.  The macro arguments are	
' defined as follows:						
'                                                              
'   SysRequest(                                               
'	 rqCode ....... The request number of the service	
'			interface.  These numbers must be in	
'			order with no omissions.  Note that the	
'			first entry in a new level is offset 0	
'			(The first entry in level 3 is 3000h)	
'	,name ......... The name of the procedure.  This field	
'			is here for convenience only and is not	
'			used internally by the macro.		
'	,exchange ..... This is the CTOS exchange that the	
'			request will be routed to by the	
'			Request interface.  User defined codes	
'			should use a zero in this field		
'	,ServiceCode .. This field is for the convenience of	
'			the Service process, and can be used in	
'			any way the process desires.		
'	,sCntInfo ..... 					
'	,nReqPbCb ..... 					
'	,nRespPbCb .... These values are put into the request	
'			block which the CTOS procedural		
'			interface creates for the user in the	
'			fields of the same name.  Note that 	
'			sCntInfo is limited to 64 bytes by the	
'			existing cluster workstation code.	
'	, ( format ) . The format is described in the	
'			following section.			
'	, ( routing) . This field defined the way the request  
'	,               routing. (see REQUEST.MDF for details)  
'	, (NetRouting).This field used by CTNet define as 	
'	,               below.		                        
'	)                                                       
'                                                              
' FORMAT 							
'	The format is a set of short macros which define the	
' order and type of arguments that are pushed onto the stack	
' when a user calls the CTOS procedural interface.  Also in	
' the format are any constants which go into the request	
' block.  The CTOS procedure initializes the request block to	
' zeros, so any zero constants may be omitted.  The macros are	
' defined as follows:						
'                                                              
'  name:           meaning:					
'	illegal ...... call to this request is an error.	
'	none ......... no arguments on stack (this call is	
'			optional).				
'	c(v,o) ....... byte value v is placed in request	
'			block at offset o in the request	
'			block.					
'	w(o) ......... the next word on the stack goes at	
'			offset o.				
'	b(o) ......... the low byte of next word on stack goes	
'			 at offset o				
'								
' For convenience, the following abbreviations are also	
' defined:							
'								
'  abbreviation:  definition:					
'	fh .......... w(12)					
'	lfa ......... w(16) w(14)				
'	p(o) ........ w(o+2) w(o)				
'	p0 .......... w(20) w(18)				
'	s0 .......... w(22)					
'	p1 .......... w(26) w(24)				
'	s1 .......... w(28)					
'	p2 .......... w(32) w(30)				
'	s2 .......... w(34)					
'	p3 .......... w(38) w(36)				
'	pbCb0 ....... w(20) w(18) w(22)			
'	pbCb1 ....... w(26) w(14) w(28)                     
'	pbCb2 ....... w(32) w(30) w(34)                     
'								
'								
' NET ROUTING 							
' The table rgNetRouting is used by the CTOS Kernel to decide whether a 
' request gets routed by file handle, by file spec, or not at all. 
' It is also used by CTOSIF.asm to determine how to expand file specs.
' The following is a set of general rules for request blocks that have
' file specs. These rules permit routing information to be encoded.
'
'	1. A request may not have more than two file specs.
'	2. The first file spec must be specified by the first pbcb pair.
'	3. If a file spec has a password, it must be specified by the pbcb
'		pair that immediately follows the pbcb for the file spec.
'	4. If one file spec has a password associated with it, then
'		all file specs in the request must have passwords.
'
'	RW		This request is a read or write and may have to be
'			be broken up in to smaller requests.
'	ESC	This request does not follow the rules above, and must be
'			handled seperately (e.g., SpoolerPassword).
'	SpecPW	All file spec pbcb pairs are followed by password pbcb pairs.
'	rFh	Route this request by the file handle.
'	DevSpec	Route this request by div spec
'	DirSpec	Route this request by dir Spec
'	FileSpec	Route this request by file spec
'	FileSpec2	Route this request by file spec (request contains 2 of them)
'	FileSpecP2S2	Route by file spec in p2s2
;

;

; Exchange definitions 
;	Exchanges 0 to 24 are reserved for CTOS processes.
;

exchNul		EQU  0
exchKbd		EQU  1		; Keyboard manager Debugger
;  NO LONGER USED***> exchSysIn	EQU  3		; System Input proccess
exchTerm	EQU  5		; Application terminator
exchLclFs	EQU  10		; File system managerUtility
exchResex	EQU  exchLclFs
exchTask	EQU  exchLclFs

;  All these are dynamically installed or not server functions

exchVideo	EQU  0
exchSplr	EQU  0
exchUFS		Equ  0
exchISAM	EQU  0
exch3270	EQU  0
exchSplrOld	EQU  0
exchQueMgr	EQU  0
exchRJE		EQU  0
exchCommLine	EQU exchLclFs
exchCommSer 	EQU  0
exchTape	EQU  0
exchX25		EQU  0
exchDBMS	EQU  0		; DBMS service
exchSNA     	EQU  0		; SNA
exchMailSer	EQU  0		; Mail Server
ExchTia		EQU  0

    exchAgent	EQU  1
    exchNotInstalled EQU  2
    exchMassIO	EQU  3		; Mass storage IO manager
    exchFilSys1	EQU  4		; File system manager Utility
    exchFilSys2	EQU  5
    exchFilSys3	EQU  6
    exchFilSys4	EQU  7
    exchChgUsrN	EQU  8		; MultiPart Change User Num Rq for FS
    exchSrpAgent EQU 9
    exchLog	EQU  10
	exchFilterPros EQU 11
	exchMem	EQU 12
	exchVp	EQU 13		; VarPart only rqs
    exchKbd	EQU 14		; Keyboard manager Debugger, maybe resident
	exchTpReq	EQU 15	; SRP Tp 8251 service

;
; FILE REQUEST.ASM 						
;  Start of System Requests.  Note:  The 0'th request MUST be present

SysRequestInit

SysRequest(0,(illegal),0,0000h,0,0,0,
	( illegal ),(rlocal),
        ( noRouting ))

SysRequest(1,SetPath,exchLclFs,0D13h,6,3,0,
		( p0 s0 p1 s1 p2 s2 ),(rLocal),
                ( noRouting ))

SysRequest(2,ClearPath,exchLclFs,0D14h,0,0,0,
		( none ),(rLocal),
                ( noRouting )) 

SysRequest(3,SetPrefix,exchLclFs,0D15h,6,1,0,
		( p0 s0 ),(rLocal),( noRouting ))

SysRequest(4,OpenFile,exchFilterPros,0001h,6,2,1,
		( c(2,34) p2 p0 s0 p1 s1 w(14) ),(rLocal),
		( FileSpec SpecPW openFh))

SysRequest(5,CreateFile,exchFilterPros,0000h,6,2,0,
		( p0 s0 p1 s1 lfa ),(rLocal),
		( FileSpec SpecPW ))

SysRequest(6,DeleteFile,exchFilSys1,0501h,2,0,0,
		( fh ),(rHandle),
		( rFh closeFh ))

SysRequest(7,RenameFile,exchFilSys1,0002h,6,2,0,
		( fh p0 s0 p1 s1 ),(rHandle),
		( rFh FileSpec SpecPW ))

SysRequest(8,GetFileStatus,exchFilSys1,0700h,6,0,1,
		( fh w(14) p0 s0 ),(rHandle),( rFh ))

SysRequest(9,SetFileStatus,exchFilSys1,0701h,6,1,0,
		( fh w(14) p0 s0 ),(rHandle),( rFh ))

SysRequest(10,CloseFile,exchFilSys1,0500h,2,0,0,
		( fh ),(rHandle),
		( rFh closeFh))

SysRequest(11,MountVolume,exchFilterPros,0800h,6,2,0,
		( p0 s0 p1 s1 ),(rLocal),
		( DevSpec SpecPW ))

SysRequest(12,DismountVolume,exchFilterPros,0801h,6,2,0,
		( p0 s0 p1 s1),(rLocal),
		( DevSpec SpecPW ))

SysRequest(13,ChangeFileLength,exchFilSys1,0503h,6,0,0,
		( fh lfa ),(rHandle),
		( rFh ))

SysRequest(14,GetDateTime,exchFilSys3,0200h,6,0,1,
		( p0 c(4,22) ),(rMasterFp),
                ( noRouting ))


SysRequest(15,GetVhb,exchFilterPros,0803h,6,1,1,
		( p0 s0 p1 s1 ),(rLocal),
		( DevSpec ))

SysRequest(16,SetDevParams,exchFilterPros,0804h,6,2,0,
		( p0 s0 p1 s1 w(12) ),(rLocal),
		( DevSpec SpecPW ))

SysRequest(17,CreateDir,exchFilterPros,0003h,6,3,0,
		( p0 s0 p1 s1 p2 s2 w(14) w(16) ),(rLocal),
		( DirSpec SpecPW ))

SysRequest(18,DeleteDir,exchFilterPros,0004h,6,2,0,
		( p0 s0 p1 s1 ),(rLocal),
		( DirSpec SpecPW ))

SysRequest(19,CloseAllFiles,exchFilterPros,0504h,0,0,0,
		( none ),(rLocal),
		( noRouting ))

SysRequest(20,QuietIO,exchFilterPros,0507h,0,0,0,
		( none ),(rLocal),
  		( noRouting ))


SysRequest(21,QueryVidHdw,exchVideo,0C03h,6,0,1,
		( p0 s0 ),(rLocal),
		( noRouting ))


SysRequest(22,LoadFontRam,exchVideo,0B00h,6,1,0,
		( fh p0 s0 ),(rLocal),
		( noRouting ))


SysRequest(23,LoadStyleRam,exchVideo,0B03h,6,1,0,
		( p0 s0 ),(rLocal),
		( noRouting ))


SysRequest(24,LoadCursorRam,exchVideo,0B02h,6,1,0,
		( p0 s0 ),(rLocal),
		( noRouting ))


SysRequest(25,ReadDirSector,exchFilterPros,0005h,6,2,1,
		( p0 s0 p1 s1 w(14) p2 c(2,35) ),(rLocal),
		( DirSpec SpecPW ))  ; *1

SysRequest(26,GetDcbOld,exchFilterPros,0805h,6,2,1,
		( p0 s0 p1 s1 p2 s2 ),(rLocal),
		( DevSpec ))

SysRequest(27,GetUcb,exchLclFs,0D17h,6,0,1,
		( p0 s0 ),(rLocal),
		( noRouting ))


SysRequest(28,Chain,exchTerm,0000h,6,2,0,
		( p0 s0 p1 s1 w(12) w(14) w(16) ),(rLocal),
		( filespec ))


SysRequest(29,LoadTask,exchTask,0A00h,6,0,0,
		( fh w(14) w(16) ),(rLocal),
		( noRouting ))


SysRequest(30,SetFhLongevity,exchFilSys1,0505h,4,0,0,
		( w(12) w(14) ),(rHandle),
		( rFh ))
                                                                 
SysRequest(31,GetFhLongevity,exchFilSys1,0506h,6,0,1,
		( fh p0 c(1,22) ),(rHandle),
		( rFh ))

SysRequest(32,ResetSubsys,exchTask,0E00h,6,0,0,
		( fh w(14) w(16) ),(rLocal),
		( noRouting ))


SysRequest(33,DeviceRead,exchMassIo,8000h,6,0,2,
		( w(12) p0 s0 lfa p1 c(2,28) ),(rLocal),
		( RW ))

SysRequest(34,DeviceWrite,exchMassIo,8001h,6,1,1,
		( w(12) p0 s0 lfa p1 c(2,28) ),(rLocal),
		( RW ))

SysRequest(35,Read,exchFilSys2,0000h,6,0,2,
		( fh p0 s0 lfa p1 c(2,28) ),(rHandle),
		( rFh RW ))

SysRequest(36,Write,exchFilSys2,0001h,6,1,1,
		( fh p0 s0 lfa p1 c(2,28) ),(rHandle),
		( rFh RW ))

SysRequest(37,DeviceReadIdAndData,exchMassIo,8002h,6,0,2,
		( w(12) p0 s0 lfa p1 c(2,28) ),(rHandle),
		( noRouting ))


SysRequest(38,Format,exchFilSys2,0003h,6,1,1,
		( w(12) p0 s0 lfa p1 c(2,28) ),(rHandle),
		( rFh RW ))

SysRequest(39,DeviceReadID,exchMassIo,8004h,6,0,2,
		( w(12) p0 s0 lfa p1 c(2,28) ),(rHandle),
		( noRouting ))


SysRequest(40,AllocExch,exchResex,0D00h,6,0,1,
		( p0 c(2,22) ),(rLocal),
		( noRouting ))


SysRequest(41,DeallocExch,exchResex,0D01h,2,0,0,
		( w(12) ),(rLocal), 
		(noRouting))


SysRequest(42,AllocMemorySL,exchResex,0D02h,6,0,1,
		( w(12) p0 c(4,22) ),(rLocal),
		(noRouting))


SysRequest(43,DeallocMemorySL,exchResex,0D03h,6,0,0,
		( p(14) w(12) ),(rLocal),
		(noRouting))

SysRequest(44,AllocMemoryLL,exchResex,0D04h,6,0,1,
		( w(12) p0 c(4,22) ),(rLocal),
		(noRouting))


SysRequest(45,DeallocMemoryLL,exchResex,0D05h,6,0,0,
		( p(14) w(12) ),(rLocal),
		(noRouting))


SysRequest(46,AllocAllMemorySL,exchResex,0D06h,6,0,2,
		( p0 p1 c(2,22) c(4,28) ),(rLocal), 
		(noRouting))


SysRequest(47,ResetMemoryLL,exchResex,0D07h,0,0,0,
		( none ),(rLocal), 
		(noRouting))


SysRequest(48,QueryMemAvail,exchResex,0D08h,6,0,1,
		( p0 c(2,22) ),(rLocal), 
		(noRouting))


SysRequest(49,OpenRTClock,exchKbd,0300h,6,1,0,
		( p0 c(12,22) ),(rLocal),
		(noRouting))


SysRequest(50,CloseRTClock,exchKbd,0400h,6,1,0,
		( p0 c(12,22) ),(rLocal),
		(noRouting))


SysRequest(51,SetDateTime,exchFilterPros,0201h,4,0,0,
		( w(12) w(14) ),(rLocal),
		(noRouting))


SysRequest(52,Beep,exchKbd,0100h,0,0,0,
		( none ),(rLocal),
		(noRouting))


SysRequest(53,ReadKbd,exchKbd,0001h,6,0,1,
		( p0 c(2,22) ),(rLocal),
		(noRouting))


SysRequest(54,ReadKbdDirect,exchKbd,0001h,6,0,1,
		( w(12) p0 c(1,22) ),(rLocal),
		(noRouting))


SysRequest(55,QueryKbdLEDs,exchKbd,0003h,6,0,1,
		( p0 c(2,22) ),(rLocal), (noRouting))


SysRequest(56,SetKbdLED,exchKbd,0004h,4,0,0,
		( w(12) w(14) ),(rLocal), (noRouting))


SysRequest(57,SetKbdUnencodedMode,exchKbd,0005h,2,0,0,
		( w(12) ),(rLocal), (noRouting))


SysRequest(58,QueryKbdState,exchKbd,0006h,6,0,1,
		( p0 c(4,22) ),(rLocal), (noRouting))


SysRequest(59,SetSysInMode,exchNul,0008h,4,0,0,
		( w(14) fh ),(rLocal), (noRouting))


SysRequest(60,ReadActionCode,exchKbd,000Ah,6,0,1,
		( p0 c(2,22) ),(rLocal), (noRouting))


SysRequest(61,QueryWSNum,exchResex,0202h,6,0,1,
		( p0 c(2,22) ),(rLocal), (noRouting))


SysRequest(62,CloseAllFilesLL,exchFilterPros,0508h,0,0,0,
		( none ),(rLocal), (noRouting))


SysRequest(63,KbdWakeUp,exchKbd,0002h,0,0,0,
		( none ),(rLocal), (noRouting))
	; *2

SysRequest(64,BeeperOff,0,0200h,0,0,0,
		( none ),(rLocal), (noRouting))
	; *2

SysRequest(65,SetKbdUnencodedModeReal,exchKbd,0005h,2,0,0,
		( w(12) ),(rLocal), (noRouting))
	; *2

SysRequest(66,KbdResetSysIn,exchNul,000Ch,0,0,0,
		( none ),(rLocal), (noRouting))
	; *2

SysRequest(67,DisableActionFinish,exchKbd,0007h,2,0,0,
		( w(12) ),(rLocal), (noRouting))


SysRequest(68,CheckpointSysIn,exchNul,0009h,0,0,0,
		( none ),(rLocal), (noRouting))


SysRequest(69,SetIntHandler,exchResex,0D0Bh,12,0,0,
		( w(12) p(14) w(18) w(20) w(22) ),(rLocal), (noRouting))


SysRequest(70,ResetKbd,exchKbd,0000h,2,0,0,
		( w(12) ),(rLocal), (noRouting))
	; *2

SysRequest(71,ResetSysIn,exchNul,0000h,2,0,0,
		( w(12) ),(rLocal), (noRouting))
	; *2

SysRequest(72,ResetAgent,exchAgent,0000h,2,0,0,
		( w(12) ),(rLocal), (noRouting))
	; *2

SysRequest(73,(reserved),0,0000h,0,0,0,
		( illegal ),(rLocal), (noRouting))


SysRequest(74,ResetVideo,exchVideo,0C00h,6,0,1,
		( b(12) b(13) b(14) b(15) p0 c(2,22) ),(rLocal), 		(noRouting))


SysRequest(75,InitVidFrame,exchVideo,0C01h,10,0,0,
		( b(12) b(13) b(14) b(15) b(16) b(17)
		   b(18) b(19) b(20) b(21) ),(rLocal), (noRouting))


SysRequest(76,InitCharMap,exchVideo,0C02h,6,0,1,
		( p0 s0 ),(rLocal), (noRouting))


SysRequest(77,SetScreenVidAttr,exchVideo,0B01h,4,0,0,
		( w(12) w(14) ),(rLocal), (noRouting))


SysRequest(78,CloseISAM,exchISAM,8400h,2,0,1,
		( w(12) p(14) c(4,18) ),(rRemote),
		( rFh closeFh ))

SysRequest(79,CreateISAM,exchISAM,0001h,0,5,1,
		( p(12) w(16) p(18) w(22) p(24) w(28)
		   p(30) w(34) p(36) w(40) p(42) c(4,46)),(rRemote),
		( FileSpec2 SpecPW ))

SysRequest(80,DeleteISAM,exchISAM,8002h,2,0,1,
		( w(12) p(14) c(4,18) ),(rRemote),
		( rFh closeFh ))

SysRequest(81,DeleteISAMRecord,exchISAM,0D803h,6,0,1,
		( w(12) p(14) p(18) c(4,22) ),(rRemote),
		( rFh ))

SysRequest(82,GetISAMRecords,exchISAM,0C004h,4,0,3,
		( w(12) b(14) p(16) w(20)
		   p(22) c(2,26) p(28) c(4,32) ),(rRemote),
		( rFh ))

SysRequest(83,LockISAM,exchISAM,0EFFFh,2,1,1,
		( w(12) p(14) w(18) p(20) c(4,24) ),(rRemote), 		(noRouting))


SysRequest(84,ModifyISAMRecord,exchISAM,0D805h,6,1,1,
		( w(12) p(14) p(18) w(22) p(24) c(4,28) ),(rRemote),
		( rFh ))

SysRequest(85,OpenISAM,exchISAM,0006h,4,2,2,
		( p(28) c(2,32) p(16) w(20) p(22) w(26)
		   w(12) w(14) p(34) c(4,38) ),(rRemote),
		( FileSpec2 SpecPW openFh ))

SysRequest(86,ReadISAMRecordByUri,exchISAM,0C007h,6,0,2,
		( w(12) p(14) p(18) w(22) p(24) c(4,28) ),(rRemote),
		( rFh ))

SysRequest(87,ReadNextISAMRecord,exchISAM,0C008h,2,0,3,
		( w(12) p(14) w(18) p(20) c(4,24) p(26)
		   c(4,30) ),(rRemote),
		( rFh ))

SysRequest(88,ReadUniqueISAMRecord,exchISAM,0C009h,4,1,3,
		( w(12) w(14) p(16) w(20) p(22) w(26)
		   p(28) c(4,32) p(34) c(4,38) ),(rRemote),
		( rFh ))

SysRequest(89,RenameISAM,exchISAM,800Ah,2,4,1,
		( w(12) p(14) w(18) p(20) w(24)
		   p(26) w(30) p(32) w(36) p(38) c(4,42) ),(rRemote),
		( rFh FileSpec2 SpecPW ))

SysRequest(90,SetISAMProtection,exchISAM,800Bh,2,2,1,
		( w(12) p(14) w(18) p(20) w(24) p(26)
		   c(4,30) ),(rRemote),
		( rFh ))

SysRequest(91,SetupISAMIterationKey,exchISAM,0EFFFh,4,1,1,
		( w(12) w(14) p(16) w(20) p(22) c(4,26) ),(rRemote),
		( noRouting ))

SysRequest(92,SetupISAMIterationPrefix,exchISAM,800Ch,4,1,1,
		( w(12) w(14) p(16) w(20) p(22) c(4,26) ),(rRemote),
		( rFh ))

SysRequest(93,SetupISAMIterationRange,exchISAM,0EFFFh,6,2,1,
		( w(12) w(14) p(18) w(22) b(16) p(24)
		   w(28) b(17) p(30) c(4,34) ),(rRemote),
		( noRouting ))

SysRequest(94,StoreISAMRecord,exchISAM,0D80Dh,2,1,2,
		( w(12) p(14) w(18) p(20) c(4,24) p(26)
		   c(4,30) ),(rRemote),
		( rFh ))

SysRequest(95,UnlockISAM,exchISAM,0EFFFh,0,0,1,
		( p(12) c(4,16) ),(rRemote), (noRouting))


SysRequest(96,PurgeISAMUser,exchISAM,000Eh,2,0,0,
		( w(12) ),(rRemote), (noRouting))


SysRequest(97,OpenFileLL,exchFilterPros,0001h,6,2,1,
		( c(2,34) p2 p0 s0 p1 s1 w(14) ),(rLocal),
		( FileSpec SpecPW openFh ))

SysRequest(98,ConvertToSys,exchResex,0D0Ch,0,0,0,
		( none ),(rLocal), (noRouting))


SysRequest(99,ServeRq,exchResex,0D0Dh,4,0,0,
		( w(12) w(14) ),(rLocal), (noRouting))


SysRequest(100,GetClusterStatus,exchSrpAgent,0000h,6,0,1,
		( w(12) p0 s0 ),(rLineNumber),
		(noRouting))


SysRequest(101,SetCommISR,exchCommLine,0303h,22,0,0,
		( w(12) p(14) p(18) p(22) p(26) p(30) ),(rLocal),
		(noRouting))


SysRequest(102,ResetCommISR,exchCommLine,0305h,2,0,0,
		( w(12) ),(rLocal),
		(noRouting))


SysRequest(103,KbAttn3270,exch3270,0000h,6,2,0,
		( c(1,22) p(18) p(24) w(28) ),(rRemote), (noRouting))


SysRequest(104,ScreenRead3270,exch3270,0001h,6,2,0,
		( c(1,22) p(18) p(24) w(28) ),(rRemote), (noRouting))


SysRequest(105,StatusRead3270,exch3270,0002h,6,2,0,
		( c(1,22) p(18) p(24) w(28) ),(rRemote), (noRouting))


SysRequest(106,ReadyForCmd3270,exch3270,0003h,6,1,1,
		( c(1,22) p(18) p(24) w(28) ),(rRemote), (noRouting))


SysRequest(107,StartEm3270,exch3270,0004h,6,1,1,
		( c(1,22) p(18) p(24) w(28) ),(rRemote), (noRouting))


SysRequest(108,StopEm3270,exch3270,0005h,2,0,0,
		( w(12) ),(rRemote), (noRouting))


SysRequest(109,CancelRq3270,exch3270,0006h,6,1,0,
		( c(1,22) p(18) ),(rRemote), (noRouting))


SysRequest(110,ReportStatus3270,exch3270,0007h,6,1,1,
		( c(1,22) p(18) p(24) w(28) ),(rRemote), (noRouting))


SysRequest(111,SetVerifyCount,exchFilSys1,0509h,2,0,0,
		( w(12) ),(rMasterFp), (noRouting))


SysRequest(112,FileSystemAbort,exchFilterPros,0508h,0,0,0,
		( none ),(rLocal), (noRouting))


SysRequest(113,QuerySpooler,exchSplrOld,0000h,0,0,0,
		( none ),(rLocal), (noRouting))


SysRequest(114,AddFileSpooler,exchSplrOld,0000h,4,4,0,
		( p(16) w(20) p(22) w(26) p(28) w(32) p(34) w(38)
		   b(12) b(13) b(14) b(15) ),(rLocal), (noRouting))


SysRequest(115,DelFileSpooler,exchSplrOld,0000h,0,2,0,
		( p(12) w(16) p(18) w(22) ),(rLocal), (noRouting))


SysRequest(116,PausePrinter,exchSplrOld,0000h,0,1,0,
		( p(12) w(16) ),(rLocal), (noRouting))


SysRequest(117,RestartPrinter,exchKbd,0500h,2,1,0,
		( p(14) w(18) w(12) ),(rFileId), (noRouting))


SysRequest(118,CancelPrint,exchSplrOld,0000h,0,1,0,
		( p(12) w(16) ),(rLocal), (noRouting))


SysRequest(119,GetSpoolerStatus,exchKbd,0600h,2,1,1,
		( p(14) w(18) w(12) p(20) w(24) ),(rFileId), 		(noRouting))


SysRequest(120,GetNxtFilePrt,exchSplrOld,0000h,0,1,1,
		( p(12) w(16) p(18) w(22) ),(rRemote), (noRouting))


SysRequest(121,SetLpISR,exchResex,0D10h,6,0,0,
		( p(14) w(12) ),(rLocal), (noRouting))


SysRequest(122,DisableCluster,exchSrpAgent,0,4,0,0,
		( w(12) w(14) ),(rMasterCp), (noRouting))


SysRequest(123,GetRunFileHdr,exchFilSys1,0E00h,6,0,1,
		( fh p0 s0 ),(rHandle),
		( rFh ))

SysRequest(124,QueryDcb,exchFilterPros,0805h,6,1,1,
		( p0 s0 p1 s1 ),(rLocal),
		( DevSpec ))

SysRequest(125,WriteLog,exchLog,0002h,6,1,0,
		( p0 s0 ),(rLocal), (noRouting))


SysRequest(126,SetCommISRRaw,exchCommLine,0304h,30,0,0,
		( w(12) p(14) p(18) p(22) p(26)
		   p(30) w(34) w(36) w(38) w(40) ),(rLocal), (noRouting))


SysRequest(127,PurgeISAMTransaction,exchISAM,0EFFFh,0,0,1,
		( p(12) c(4,16) ),(rRemote), (noRouting))


SysRequest(128,EndISAMTransaction,exchISAM,0EFFFh,0,0,1,
		( p(12) c(4,16) ),(rRemote), (noRouting))


SysRequest(129,GetISAMRecordsHold,exchISAM,0F004h,4,0,3,
		( w(12) b(14) p(16) w(20)
		   p(22) c(2,26) p(28) c(4,32) ),(rRemote),
		(rFh))


SysRequest(130,HoldISAMRecord,exchISAM,0D00Fh,6,0,1,
		( w(12) p(14) p(18) c(4,22) ),(rRemote),
		(rFh))


SysRequest(131,ReadISAMRecordByUriHold,exchISAM,0F007h,6,0,2,
		( w(12) p(14) p(18) w(22) p(24) c(4,28) ),(rRemote),
		(rFh))


SysRequest(132,ReadNextISAMRecordHold,exchISAM,0F008h,2,0,3,
		( w(12) p(14) w(18) p(20) c(4,24) p(26)
		   c(4,30) ),(rRemote), (rFh))


SysRequest(133,ReadUniqueISAMRecordHold,exchISAM,0F009h,4,1,3,
		( w(12) w(14) p(16) w(20) p(22) w(26)
		   p(28) c(4,32) p(34) c(4,38) ),(rRemote), 		(rFh))


SysRequest(134,ReleaseISAMRecord,exchISAM,0D410h,6,0,1,
		( w(12) p(14) p(18) c(4,22) ),(rRemote), (rFh))


SysRequest(135,SetupISAMIteration,exchISAM,0EFFFh,4,1,1,
		( w(12) w(14) p(16) w(20) p(22) c(4,26) ),(rRemote), 		(noRouting))


SysRequest(136,StartISAMTransaction,exchISAM,0EFFFh,4,1,1,
		( b(12) w(14) p(16) w(20) p(22) c(4,26) ),(rRemote), 		(noRouting))


SysRequest(137,AddQueueEntry,exchQueMgr,0000h,6,3,0,
		( p(18) w(22) b(12) b(13)   w(14)
		   p(24) w(28) p(30) c(4,34) w(16) ),(rRemote),
		( DevSpec ))

SysRequest(138,RemoveKeyedQueueEntry,exchQueMgr,0001h,4,3,0,
		( p(16) w(20) p(22) w(26) w(12) p(28) w(32) w(14) ),(rRemote),
		( DevSpec ))

SysRequest(139,ReadNextQueueEntry,exchQueMgr,0002h,4,1,2,
		( p(16) w(20) p(12) p(22) w(26) p(28) w(32) ),(rRemote),
		( DevSpec ))

SysRequest(140,ReadKeyedQueueEntry,exchQueMgr,0003h,4,3,2,
		( p(16) w(20) p(22) w(26) w(12) 
		   p(28) w(32) w(14) p(34) w(38) p(40) w(44) ),(rRemote),
		( DevSpec ))

SysRequest(141,MarkNextQueueEntry,exchQueMgr,0004h,2,1,2,
		( p(14) w(18) b(12) p(20) w(24) p(26) w(30) ),(rRemote),
		( DevSpec ))

SysRequest(142,MarkKeyedQueueEntry,exchQueMgr,0005h,4,3,2,
		( p(16) w(20) p(22) w(26) w(12) p(28) 
		   w(32) w(14) p(34) w(38) p(40) w(44) ),(rRemote),
		( DevSpec ))

SysRequest(143,RemoveMarkedQueueEntry,exchQueMgr,0006h,4,1,0,
		( p(16) w(20) p(12) ),(rRemote),
		( DevSpec ))

SysRequest(144,UnMarkQueueEntry,exchQueMgr,0007h,4,1,0,
		( p(16) w(20) p(12) ),(rRemote),
		( DevSpec ))

SysRequest(145,ReWriteMarkedQueueEntry,exchQueMgr,0008h,4,2,0,
		( p(16) w(20) p(12) p(22) w(26) ),(rRemote),
		( DevSpec ))

SysRequest(146,EstablishQueueServer,exchQueMgr,0009h,4,1,0,
		( p(16) w(20) w(12) b(14) ),(rRemote),
		( DevSpec ))

SysRequest(147,TerminateQueueServer,exchQueMgr,000Ah,0,1,0,
		( p(12) w(16) ),(rRemote), (noRouting))


SysRequest(148,PurgeQueueServer,exchQueMgr,000Bh,2,0,0,
		( w(12) ),(rRemote), (noRouting))


SysRequest(149,SignoffRJE,exchRJE,0000h,2,0,0,
		( w(12) ),(rRemote), (noRouting))


SysRequest(150,SignonRJE,exchRJE,0000h,0,2,0,
		( p(12) w(16) p(18) w(22) ),(rRemote), (noRouting))


SysRequest(151,StatusRJE,exchRJE,0000h,0,0,2,
		( p(12) c(2,16) p(18) w(22) ),(rRemote), (noRouting))


SysRequest(152,AcceptCommCall,exchCommSer,0000h,4,0,0,
		( w(12) w(14) ),(rLocal), (noRouting))


SysRequest(153,CloseAllCommLines,exchCommSer,0001h,2,0,0,
		( w(12)),(rLocal), (noRouting))


SysRequest(154,CloseCommLine,exchCommSer,0002h,4,0,0,
		( w(12) w(14) ),(rLocal), (noRouting))


SysRequest(155,DialComm,exchCommSer,0003h,2,1,0,
		( w(12) p(14) w(18) ),(rLocal), (noRouting))


SysRequest(156,DisconnectComm,exchCommSer,0004h,2,0,0,
		( w(12) ),(rLocal), (noRouting))


SysRequest(157,FlushCommBuffer,exchCommSer,0005h,4,0,0,
		( w(12) b(14) ),(rLocal), (noRouting))


SysRequest(158,GetCommParameters,exchCommSer,0006h,2,0,1,
		( w(12) p(14) c(20,18) ),(rlocal), (noRouting))


SysRequest(159,OpenCommLine,exchCommSer,0007h,4,2,1,
		( b(12) p(16) w(20) p(22) w(26) w(14) p(28) c(2,32) ),(rlocal), (noRouting))


SysRequest(160,ReadComm,exchCommSer,0008h,4,0,2,
		( w(12) w(14) p(16) w(20) p(22) c(2,26) ),(rlocal),
		(noRouting))


SysRequest(161,SetCommParameters,exchCommSer,0009h,2,1,0,
		( w(12) p(14) c(20,18) ),(rlocal), (noRouting))


SysRequest(162,WriteComm,exchCommSer,000Ah,4,1,1,
		( w(12) w(14) p(16) w(20) p(22) c(2,26) ),(rlocal),
		(noRouting))


SysRequest(163,BreakComm,exchCommSer,000Bh,2,0,0,
		( w(12) ),(rlocal), (noRouting))


SysRequest(164,ResetQueMgr,exchQueMgr,0000h,2,0,0,
		( w(12) ),(rRemote), (noRouting))


SysRequest(165,NotifyNextIncomingCall,exchX25,0,8,1,3,
		( w(12) p(38) c(2,42) p(26) w(30) p(32) c(2,36)
		   p(20) w(24) w(14) w(16) w(18) ),(rRemote),
		(noRouting))


SysRequest(166,AcceptX25Call,exchX25,0,6,2,0,
		( w(12) p(18) w(22) p(24) w(28) w(16) ),(rRemote),
		(noRouting))


SysRequest(167,InitiateX25Call,exchX25,0,6,3,3,
		( w(12) p(36) c(2,40) p(42) w(46) p(48) c(2,52)
		   p(30) w(34) p(18) w(22) p(24) w(28) w(14) ),(rRemote), (noRouting))


SysRequest(168,ClearX25Call,exchX25,0,6,1,0,
		( w(12) w(14) p(18) w(22) ),(rRemote), (noRouting))


SysRequest(169,PurgeX25User,exchX25,0,2,0,0,
		( w(12) ),(rRemote), (noRouting))


SysRequest(170,ReadX25Packet,exchX25,0,6,0,3,
		( w(12) p(18) w(22) p(24) c(2,28)
		   p(30) c(1,34) w(14) ),(rRemote), (noRouting))


SysRequest(171,WriteX25Packet,exchX25,0,6,1,0,
		( w(12) w(14) p(18) w(22) ),(rRemote), (noRouting))


SysRequest(172,WriteX25Interrupt,exchX25,0,4,0,0,
		( w(12) w(14) ),(rRemote), (noRouting))


SysRequest(173,ResetX25Call,exchX25,0,4,0,0,
		( w(12) w(14) ),(rRemote), (noRouting))


SysRequest(174,QueryX25Status,exchX25,0,8,0,2,
		( w(12) p(20) w(24) b(14) b(15)
		   w(16) w(18) p(26) c(1,30) ),(rRemote), (noRouting))


SysRequest(175,ConnectX25Permanent,exchX25,0,2,0,1,
		( w(12) p(14) c(2,18) ),(rRemote), (noRouting))


SysRequest(176,DeletePartition,exchTask,0F01h,2,0,0,
		( w(12) ),(rLocal), (noRouting))


SysRequest(177,GetPartitionHandle,exchTask,0F02h,0,1,1,
		( p(12) w(16) p(18) c(2,22) ),(rLocal), (noRouting))


SysRequest(178,LoadPrimaryTask,exchTerm,0000h,6,2,0,
		( w(12) p(18) w(22) p(24) w(28) w(14) ),(rLocal),
		(noRouting))


SysRequest(179,TerminatePartition,exchTask,0F03h,2,0,0,
		( w(12) ),(rLocal), (noRouting))


SysRequest(180,VacatePartition,exchTask,0E01h,2,0,0,
		( w(12) ),(rLocal), (noRouting))


SysRequest(181,CreatePartition,exchTask,0F00h,6,1,1,
		( p(18) w(22) w(12) b(14) p(24) c(2,28) ),(rLocal),
		(noRouting))


SysRequest(182,SetPartitionLock,exchTask,0F04h,2,0,0,
		( b(12) ),(rLocal), (noRouting))


SysRequest(183,SetPartitionExch,exchTask,0F05h,2,0,0,
		( w(12) ),(rLocal), (noRouting))


SysRequest(184,GetPartitionExch,exchTask,0F06h,2,0,1,
		( w(12) p(14) c(2,18) ),(rLocal), (noRouting))


SysRequest(185,GetPartitionStatus,exchTask,0F07h,4,0,1,
		( w(12) w(14) p(16) w(20) ),(rLocal), (noRouting))


SysRequest(186,SetExitRunFile,exchTask,0D09h,6,2,0,
		( p(18) w(22) p(24) w(28) w(12) ),(rLocal),
		(noRouting))


SysRequest(187,QueryExitRunFile,exchTask,0D0Ah,6,0,3,
		( p(18) w(22) p(24) w(28) p(30) c(2,34) ),(rLocal),
		(noRouting))


SysRequest(188,ConfigureSpooler, exchSplr,0000h,6,3,0,
		( b(12) p0 s0 p1 s1 p2 s2 b(13) b(14) ),(rMasterFp),
		( FileSpecP2S2 ))

SysRequest(189,SpoolerPassword,exchSplr,0001h,6,2,0,
		( p0 s0 p1 s1 ),(rMasterFp), (noRouting))


SysRequest(190,OpenTape,exchTape,0,6,1,1,
		( p0 s0 b(12) b(13) b(14) w(16) p1 c(2,28) ),(rRemote),
		(noRouting))

SysRequest(191,ReadTapeRecords,exchTape,1,6,0,3,
		( fh w(14) p0 s0 p1 c(2,28) p2 c(2,34) ),(rFileId),
		(noRouting))

SysRequest(192,WriteTapeRecords,exchTape,2,6,1,2,
		( fh w(14) p0 s0 p1 c(2,28) p2 c(2,34) ),(rFileId),
		(noRouting))

SysRequest(193,TapeOperation,exchTape,3,6,0,0,
		( fh b(14) b(15) w(16) ),(rFileId),
		(noRouting))

SysRequest(194,CloseTape,exchTape,4,2,0,0,
		( fh ),(rFileId),
		(noRouting))

SysRequest(195,PurgeTapeUser,exchTape,5,2,0,0,
		( w(12) ),(rRemote))

SysRequest(196,TapeStatus,exchTape,6,6,0,1,
		( fh p0 c(2,22) ),(rFileId),(noRouting))

SysRequest(197,ResetSplr,exchSplr,0000h,2,0,0,
		( w(12) ),(rLocal),(noRouting))


SysRequest(198,ModifyISAMRecordByKey,exchISAM,0F811h,4,1,2,
		( w(12) w(14) p(16) w(20) p(22) c(4,26) 
		   p(28) c(4,32) ),(rRemote), (rFh))


SysRequest(199,DeleteISAMRecordByKey,exchISAM,0F812h,4,1,2,
		( w(12) w(14) p(16) w(20) p(22) c(4,26) 
		   p(28) c(4,32) ),(rRemote), (rFh))


SysRequest(200,LogRemote,exchLog,0001h,6,2,0,
		( p0 s0 p1 s1 ),(rMasterFp), (noRouting))


SysRequest(201,VacateParCleanup,exchAgent,0000h,0,0,0,
		( none ),(rLocal), (noRouting))


SysRequest(202,GetWsUserName,exchResex,0203h,6,0,1,
		( w(12) p0 s0 ),(rLocal), (noRouting))


SysRequest(203,SetWsUserName,exchResex,0204h,6,1,0,
		( p0 s0 ),(rLocal), (noRouting))


SysRequest(204,FinishISAMCommit,exchISAM,0013h,0,1,1,
		( p(12) w(16) p(18) c(4,22) ),(rRemote), (DevSpec))


SysRequest(205,HoldISAMDataSet,exchISAM,0D014h,4,0,1,
		( w(12) b(14) p(16) c(4,20) ),(rRemote), (rFh))


SysRequest(206,ReleaseISAMDataSet,exchISAM,0D415h,2,0,1,
		( w(12) p(14) c(4,18) ),(rRemote), (rFh))


SysRequest(207,RollbackISAMTransaction,exchISAM,0016h,0,1,1,
		( p(12) w(16) p(18) c(4,22) ),(rRemote), (DevSpec))


SysRequest(208,SetISAMTransactionParams,exchISAM,0017h,0,2,1,
		( p(12) w(16) p(18) w(22)
		   p(24) c(4,28) ),(rRemote), (DevSpec))


SysRequest(209,StartISAMCommit,exchISAM,0018h,0,2,1,
		( p(12) w(16) p(18) w(22)
		   p(24) c(4,28) ),(rRemote), (DevSpec))


SysRequest(210,SetupISAMIterationLimits,exchISAM,8019h,6,2,1,
		( w(12) w(14) b(16) p(18) w(22)
		   p(24) w(28) p(30) c(4,34) ),(rRemote), (rFh))


SysRequest(211,BeginISAMTransaction,exchISAM,001Ah,0,1,2,
		( p(12) w(16) p(18) c(7,22)
		   p(24) c(4,28) ),(rRemote), (DevSpec))


SysRequest(212,DbResourceRequest,exchDBMS,0FFFFh,10,3,3,
		 ( none ),(rRemote), (DevSpec openFh ))


SysRequest(213,DbNodeRequest,exchDBMS,0FFFFh,10,3,3,
		 ( none ),(rRemote), (rFh closeFh))


SysRequest(214,DbHandleRequest,exchDBMS,0FFFFh,10,3,3,
		 ( none ),(rRemote), (rFh))


SysRequest(215,ChangeOpenMode,exchFilSys1,0006h,6,1,0,
		 ( fh p0 s0 w(14) ),(rHandle),
		( rFh SpecPW ))

SysRequest(216,GetDirStatus,exchFilterPros,0007h,6,2,1,
		 ( p0 s0 p1 s1 w(12) p2 s2 ),(rLocal),
		( DirSpec SpecPW ))

SysRequest(217,SetDirStatus,exchFilterPros,0008h,6,3,0,
		 ( p0 s0 p1 s1 w(12) p2 s2 ),(rLocal),
		( DirSpec SpecPW ))

SysRequest(218,ChangeUserNumQmg,exchQueMgr,0000h,2,0,0,
		 ( w(12) ),(rRemote), (noRouting))


SysRequest(219,ChangeUserNumFs,exchFilterPros,0D13h,2,0,0,
		 ( w(12) ),(rLocal), (noRouting))


SysRequest(220,ReadSNAPIU,exchSNA,0,6,0,4,
		( w(12) w(14) w(16) p(18) w(22) p(24) w(28)
		   p(30) w(34) p(36) w(40) ),(rRemote), (rFh))


SysRequest(221,WriteSNAPIU,exchSNA,0,2,1,0,
		( w(12) p(14) w(18) ),(rRemote), (rFh))


SysRequest(222,XWriteSNAPIU,exchSNA,0,2,1,0,
		( w(12) p(14) w(18) ),(rRemote), (rFh))


SysRequest(223,AttachLu,exchSNA,0,4,0,1,
		( w(12) p(16) c(2,20) b(14)  ),(rRemote), (noRouting))


SysRequest(224,InitiateSNASession,exchSNA,0,2,5,0,
		( w(12) p(14) w(18) p(20) w(24) p(26)
		   w(30) p(32) w(36) p(38) w(42) ),(rRemote), (rFh))


SysRequest(225,NotifyNextIncomingBind,exchSNA,0,4,0,2,
		( w(12) w(14) p(16) w(20) p(22) w(26) ),(rRemote),
		(rFh))


SysRequest(226,TerminateSNASession,exchSNA,0,2,0,0,
		( w(12) ),(rRemote), (rFh))


SysRequest(227,AcceptSNASession,exchSNA,0,2,1,0,
		( w(12) p(14) w(18) ),(rRemote), (rFh))


SysRequest(228,RejectSNASession,exchSNA,0,2,1,0,
		( w(12) p(14) w(18) ),(rRemote), (rFh))


SysRequest(229,PurgeSNAUser,exchSNA,0,2,0,0,
		( w(12) ),(rRemote), (noRouting))


SysRequest(230,CloseSNASession,exchSNA,0,2,1,0,
		( w(12) p(14) w(18) ),(rRemote), (rFh))


SysRequest(231,DetachLu,exchSNA,0,2,0,0,
		( w(12) ),(rRemote), (rFh CloseFh))
 
SysRequest(232,QuerySNAStatus,exchSNA,0,8,0,2,
		( w(12) p(20) w(24) b(14) b(15) 
		   w(16) w(18) p(26) c(1,30) ),(rRemote), (FileSpec))

SysRequest(233,TerminateSNAUser,exchSNA,0,2,0,0,
		( w(12) ),(rRemote), (noRouting))

SysRequest(234,AcknowledgeMailReceipt,exchMailSer,0,6,1,0,
		( w(12) p(18) c(12,22) w(14) w(16) ),(rRemote),
		( rFh ))

SysRequest(235,CheckForMail,exchMailSer,1,4,1,2,
		( p(16) w(20) p(12) p(22) c(2,26) p(28) c(2,32) ),(rRemote),
		( DevSpec ))

SysRequest(236,ConfigureMail,exchMailSer,2,4,2,0,
		( w(12) w(14) p(16) w(20) p(22) w(26) ),(rRemote),
		( rFh ))

SysRequest(237,ConnectNextMailCenter,exchMailSer,3,2,0,2,
		( w(12) p(14) c(2,18) p(20) w(24) ),(rRemote),
		( rFh openFh))

SysRequest(238,EstablishMailConnection,exchMailSer,4,0,2,2,
		( p(12) w(16) p(18) w(22) p(24) c(2,28) p(30) w(34) ),(rRemote),
		( DevSpec openFh))

SysRequest(239,PurgeMailUser,exchMailSer,5,2,0,0,
		( w(12) ),(rRemote), (noRouting))

SysRequest(240,QueryMailConfiguration,exchMailSer,6,4,2,2,
		( w(12) w(14) p(16) w(20) p(22) w(26)
		   p(28) w(32) p(34) c(2,38) ),(rRemote),
		( rFh ))

SysRequest(241,QueryMailStatus,exchMailSer,7,6,0,2,
		( w(12) w(14) w(16) p(18) w(22) p(24) c(2,28) ),(rRemote),
		( rFh ))

SysRequest(242,QueryMailUniqueId,exchMailSer,8,2,0,1,
		( w(12) p(14) c(4,18) ),(rRemote),
		( rFh ))

SysRequest(243,QueryServerForUser,exchMailSer,9,0,2,1,
		( p(12) w(16) p(18) w(22) p(24) c(2,28) ),(rRemote),
		( DevSpec ))

SysRequest(244,ReceiveMail,exchMailSer,10,2,0,3,
		( w(12) p(14) w(18) p(20) c(2,24) p(26) c(12,30) ),(rRemote),
		( rFh ))

SysRequest(245,ResetMailServer,exchMailSer,11,2,0,0,
		( w(12) ),(rRemote), (noRouting))

SysRequest(246,SendMail,exchMailSer,12,4,2,1,
		( w(12) p(16) w(20) p(22) w(26) 
		   p(28) c(12,32) w(14) ),(rRemote),
		( rFh ))

SysRequest(247,SignoffMailUser,exchMailSer,13,4,1,0,
		( p(16) w(20) p(12) ),(rRemote),
		( DevSpec ))

SysRequest(248,TerminateMailConnection,exchMailSer,14,2,0,0,
		( w(12) ),(rRemote),
		( rFh closeFh ))

SysRequest(249,ValidateMail,exchMailSer,15,2,2,2,
		( w(12) p(14) w(18) p(20) w(24)
		   p(26) c(2,30) p(32) c(2,36) ),(rRemote),
		( rFh ))

SysRequest(250,SetMailAgentStatus,exchMailSer,16,2,1,0,
		( w(12) p(14) w(18) ),(rRemote),
		( rFh ))

SysRequest(251,PurgeMailUniqueId,exchMailSer,17,0,0,0,
		( none ),(rRemote), (noRouting))

SysRequest(252,SetNode,exchLclFs,0D16h,6,1,0,
		( pbcb0 ),(rLocal),
		(noRouting))

SysRequest(253,ExpandSpec,exchFilterPros,0806h,6,2,1,
		( pbcb0 pbcb1 pbcb2 fh ),(rLocal),
		( FileSpec SpecPW ))

SysRequest(254,QueryExchange,exchResex,0D18h,6,0,1,
		( fh p0 c(2,22) ),(rLocal),
		(noRouting))

SysRequest(255,SetVideoTimeout,0,000Bh,2,0,0,
		( w(12) ),(rLocal),
		(noRouting))

SysRequest(256,ReadActionKbd,0,000Ch,6,0,1,
		( b(12) p0 c(1,22) ),(rLocal),
		(noRouting))

SysRequest(257,ReadKbdStatus,0,000Ch,6,0,2,
		( w(12) p0 c(2,22) p1 c(1,28) ),(rLocal),
		(noRouting))

SysRequest(258,NotifyCM,0,0,6,1,0,
		( w(12) pbcb0 ),(rLocal),
		(noRouting))

SysRequest(259,ChangeUserNumMail,exchMailSer,18,2,0,0,
		( w(12) ),(rRemote),
		(noRouting))

SysRequest(260,QuietMailUser,exchMailSer,19,2,0,0,
		( w(12) ),(rRemote),
		(noRouting))

SysRequest(261,OSVersion,exchLclFs,0206h,0,0,1,
		( p(12) c(2,16)),(rLocal),
		(noRouting))

SysRequest(262,LoadInterActiveTask,exchTerm,0000h,6,2,0,
        ( w(12) p(18) w(22) p(24) w(28) w(14) w(16)),(rLocal),
		(noRouting))

SysRequest(263,TerminateISAMServer,exchISAM,001Bh,0,0,2,
		( p(12) c(2,16) p(18) c(4,22)),(rRemote),
		(noRouting))

SysRequest(264,MapXBusWindow,0,0D1Ah,6,0,2,
        ( b(12) b(13) p(18) c(4,22) w(14) p(24)
            c(2,28) w(16)),(rLocal),
		(noRouting))

SysRequest(265,QuietKbdForSwap,0,0000h,2,0,0,
		( w(12) ),(rLocal),
		(noRouting))

SysRequest(266,Purge3270Em,0,0000h,6,0,0,
		(  ),(rRemote),
		(noRouting))

SysRequest(267,PurgeX25,0,0000h,6,0,0,
		(  ),(rRemote),
		(noRouting))

SysRequest(268,SetTrapHandler,exchResex,0D0Bh,12,0,0,
		( w(12) p(14)  c(0FFh, 22) ),(rLocal),
		(noRouting))

SysRequest(269,QueryNodeForMailUser,0,20,0,2,2,
	 	( p(12) w(16) p(18) w(22) p(24) w(28) p(30)
			c(2,34) ),(rRemote),
		( DevSpec ))

SysRequest(270,(CtNetTermination),0,0000h,2,0,0,
		( none ),(rLocal),
		(noRouting))

SysRequest(271,QueryRequestInfo,ExchResex,0D18h,6,0,1,
		( fh pbcb0 ),(rLocal),
		(noRouting))

SysRequest(272,GetUserStatus,'exchLocalfile'0,0206h,6,0,1,
		( fh pbcb0 ),(rLocal),
		(noRouting))

SysRequest(273,CMTermination,0,0000h,2,0,0,
		( none ),(rLocal),
		(noRouting))

SysRequest(274,FilterProsTermination,0,0000h,2,0,0,
		( none ),(rLocal),
		(noRouting))

SysRequest(275,VacatePartitionA,0,0E01h,2,0,0,
		( w(12) ),(rLocal),
		(noRouting))

SysRequest(276,VacatePartitionB,0,0E02h,2,0,0,
		( w(12) ),(rLocal),
		(noRouting))

SysRequest(277,SetVectorArea,exchResex,0D1Bh,6,0,1,
		(fh w(14) p0 c(0,22)),(rLocal),
		(noRouting))

SysRequest(278,AllocAreaSL,exchResex,0D1Ch,6,0,1,
		(w(12) p0 c(4,22)),(rLocal),
		(noRouting))

SysRequest(279,ExpandAreaSL,exchResex,0D1Dh,6,0,1,
		(w(12) w(14) p0 c(2,22)),(rLocal),
		(noRouting))

SysRequest(280,ExpandAreaLL,exchResex,0D1Eh,6,0,1,
		(w(12) w(14) p0 c(2,22)),(rLocal),
		(noRouting))

SysRequest(281,ShrinkAreaSL,exchResex,0D1Fh,6,0,0,
		(p(14) w(12)),(rLocal),
		(noRouting))

SysRequest(282,ShrinkAreaLL,exchResex,0D20h,6,0,0,
		(p(14) w(12)),(rLocal),
		(noRouting))

SysRequest(283,QueryBigMemavail,exchResex,0D21h,6,0,1,
		( p0 c(4,22)),(rLocal),
		(noRouting))

SysRequest(284,CreateAlias,exchResex,0D22h,6,0,1,
		( p(14) p0 c(4,22)),(rLocal),
		(noRouting))

SysRequest(285,SetSegmentAccess,exchResex,0D23h,6,0,0,
		(w(12) b(14)), (rLocal),
		(noRouting))

SysRequest(286,SetColorData,0,0C04h,0,2,2,
		(p(12) w(16) pbcb0 pbcb1 pbcb2),(rLocal),
		(noRouting))

SysRequest(287,ProgramColorMapper,0,0,0,2,2,
		(p(12) w(16) pbcb0 pbcb1 pbcb2),(rLocal),
		(noRouting))

SysRequest(288,SetCommISRRawSFN,exchCommLine,0304h,30,0,0,
		(w(12) p(14) p(18) p(22) p(26) p(30) w(34) w(36) w(38) w(40)),(rLocal),
		(noRouting))

SysRequest(289,OpenQueue,0,0,4,2,0,
		(p(16) w(20) p(22) w(26) w(12) w(14)), (rLocal),
		(noRouting))

SysRequest(290,ResetMemorySL,0,09H,0,0,0,
		(None),(rLocal),
		(noRouting))


SysRequest(291,ResetAllSegs,0,0AH,0,0,0,
		(None),(rLocal),
		(noRouting))


SysRequest(292,FreeLargeLL,0,0BH,0,0,0,
		(None),(rLocal),
		(noRouting))


SysRequest(293,LoadFile,0,0A00h,8,0,0,
		( fh w(14) w(16) c(0,18)'reserve extra word' ),(rLocal),
		( noRouting ))

SysRequest(294,ReOpenFile,exchFilterPros,0001h,6,2,1,
		( c(2,34) p2 pbcb0  pbcb1 w(14) ),(rLocal),
		( FileSpec SpecPW openFh))

SysRequest(295,SwapinContext,0,0,2,0,0,
		(fh),(rLocal),
		(noRouting))

SysRequest(296,CreateUser,0,0F00h,6,1,1,
		( p(18) w(22) w(12)  c(4,14) p(24) c(2,28) w(16)),(rLocal),
		( noRouting))

SysRequest(297,NotUsed,0,0h,6,0,1,
		( ),(rLocal),
		( noRouting))

SysRequest(298,SetKbdHandler,0,0D24h,6,0,0,
		( p(14) w(12)), (rlocal),
		( noRouting))

SysRequest(299,AllocateMemoryReal,0,026h,6,0,1,
		( w(12) p0 c(4,22)), (rlocal),
		( noRouting))

                                       
SysRequest(300,DeAllocateMemoryReal,0,027h,6,0,0,
		( p(14) w(12)), (rlocal),
		( noRouting))

SysRequest(301,CallSourceDbgNub,exchKbd,0600h,6,1,1,
        ( fh p0 c(2,22) p1 c(4,28) ), (rLocal),
        ( noRouting ))

SysRequest(302,QueryNodeName,0,0,0,0,2,
		( p(12) w(16) p(18) c(2,22)), (rLocal),
		( NoRouting))

SysRequest(303,ReadSwap,0,0,6,0,3,
		( fh p(14) pbcb0 p1 c(2,28) p2 c(2,34)), (rLocal)
		( NoRouting))


SysRequest(304,WriteSwap,0,0,6,1,0,
		( fh p(14) pbcb0 ), (rLocal),
		( NoRouting))


SysRequest(305,DeactiveRunFile,0,0,2,0,0,
		( fh ), (rLocal),
		( NoRouting))

;Requests 307, 308, 309 reserved for Burroughs
SysRequest(307,BurroughsReserve,0,0,0,0,0,
		( ),( rLocal ),
		( noRouting ))

SysRequest(308,BurroughsReserve,0,0,0,0,0,
		( ),( rLocal ),
		( noRouting ))

SysRequest(309,BurroughsReserve,0,0,0,0,0,
		( ),( rLocal ),
		( noRouting ))

SysRequest(310,Sync1,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))

SysRequest(311,Sync2,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))

SysRequest(312,Sync3,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))

SysRequest(313,Sync4,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))

SysRequest(314,Sync5,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))

SysRequest(315,Sync6,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))

SysRequest(316,Sync7,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))

SysRequest(317,Sync8,exchNotInstalled,0,2,0,1,
		( w(12) p(14) w(18) ), ( rRemote ),
		( noRouting ))



;  The level 1 block at 1000h has no procedural interfaces.

Request(1000h,ChangeUserNumISAM,exchISAM,001Ch,2,0,0,( w(12) ),(rRemote), (noRouting))
Request(1001h,QuietISAMUser,exchISAM,0001Dh,2,0,0,( w(12) ),(rRemote), (noRouting))

Request(1002h,QuietContext,exchTerm,0003h,2,0,0,
		( w(12) ),(rRemote),
		( noRouting ))

Request(1003h,QuietQMGR,exchQueMgr,0h,2,0,0,
		( w(12) ),(rRemote),
		( noRouting ))

Request(1004h,QuietSplr,exchSplr,0h,2,0,0,
		( w(12) ),(rRemote),
		( noRouting ))

Request(1005h,Execfh,exchTerm,0005h,4,0,0,
		( w(12) w(14) ),(rHandle),
		( noRouting ))

Request(1006h,InitCommLine,exchCommLine,0300h,6,2,1,
		( pbcb0 pbcb1 pbcb2 ),(rLocal),
		( noRouting ))

Request(1007h,ResetCommLine,exchCommLine,0301h,6,0,0,
		(w(12) ),(rLocal),
		( noRouting ))

Request(1008h,ChangeCommLineBaudRate,exchCommLine,0302h,6,0,0,
		(w(12) w(14) w(16) ),(rLocal),
		( noRouting ))

Request(1009h,TerminateCommLine,exchNotInstalled,0000h,2,0,0,
		(w(12) ),(rLocal),
		( noRouting ))

Request(100Ah,ChangeUserNumCommLine,exchNotInstalled,0000h,2,0,0,
		(w(12) ),(rLocal),
		( noRouting ))

Request(100Bh,WaitSync,exchNotInstalled,0000h,2,0,0,
		(none),(rRemote),(noRouting))

Request(100Ch,NewTapeIO,exchNotInstalled,0000h,6,0,3,
		(none),(rRemote),(noRouting))

Request(100Dh,NewTapeIO,exchNotInstalled,0000h,6,1,2,
		(none),(rRemote),(noRouting))

Request(100Eh,ReMakeFh,exchFilSys1,0403h,6,0,1,
		( fh p0 c(2,22) ),(rHandle),
		( rFh ))


;  The level 2 block at 2000h has procedural interfaces.

Request(2000h,SdlcOpen,0,0000h,2,0,1,( w(12) p(14) c(2,18)),(rRemote), (noRouting))
Request(2001h,SdlcClose,0,0000h,2,0,0,( w(12) ),(rRemote), (noRouting))
Request(2002h,SdlcInit,0,0000h,2,1,0,( w(12) p(14) w(18)),(rRemote), (noRouting))
Request(2003h,SdlcStat,0,0000h,4,0,1,( w(12) w(14) p(16) w(20)),(rRemote), (noRouting))
Request(2004h,SdlcRead,0,0000h,2,0,2,( w(12) p(14) w(18) p(20) c(2,24)),(rRemote), (noRouting))
Request(2005h,SdlcWrite,0,0000h,2,1,1,(w(12)p(14)w(18)p(20) c(2,24)),(rRemote), (noRouting))
Request(2006h,TerminateSdlc,0,0,2,0,0,( w(12) ),(rRemote), (noRouting))
Request(2007h,PurgeSdlc,0,0,2,0,0,( w(12) ),(rRemote), (noRouting))
Request(2008h,BscOpen,0,0000h,6,1,1,( c(2,28) p1 p0 s0 w(14)),(rRemote), (noRouting))
Request(2009h,BscIoctl,0,0000h,6,2,0,( fh p0 c(1,22) p1 s1 ),(rRemote), (noRouting))
Request(200Ah,BscRead,0,0000h,6,1,1,( fh p0 s0 p1 s1),(rRemote), (noRouting))
Request(200Bh,BscWrite,0,0000h,6,1,1,( fh p0 s0 p1 s1 ),(rRemote), (noRouting))
Request(200Ch,BscClose,0,0000h,6,0,0,( fh ),(rRemote), (noRouting))
Request(200Dh,TerminateBsc,0,0,2,0,0,( w(12) ),(rRemote), (noRouting))
Request(200Eh,PurgeBsc,0,0,2,0,0,( w(12) ),(rRemote), (noRouting))

;
;  The level 3 block at 3000h has no procedural interfaces
;
;
Request(3000h,PtResponse,0,0,0,0,0,
		( none ),(rLocal), (noRouting))

Request(3001h,MegaGetStatistics,exchResex,0205h,2,0,1,
		( none ),(rFileId), (noRouting))

Request(3002h,RemoteBoot, exchFilSys1, 0207h, 4, 0, 0,
		( none ),(rHandle), (noRouting))

Request(3003h,UFSOpen, exchUFS, 0, 26, 1, 1, (none),(rLocal), (noRouting))

Request(3004h,UFSRead, exchUFS, 0, 12, 0, 2, (none),(rLocal), (noRouting))

Request(3005h,UFSWrite, exchUFS, 0, 12, 1, 1, (none),(rLocal), (noRouting))

Request(3006h,UFSClose, exchUFS, 0, 12, 0, 0, (none),(rLocal), (noRouting))

Request(3007h,UFSAccess, exchUFS, 0, 22, 1, 1, (none),(rLocal), (noRouting))

Request(3008h,UFSLink, exchUFS, 0, 28, 1, 0, (none),(rLocal), (noRouting))

Request(3009h,UFSDelete, exchUFS, 0, 20, 1, 0, (none),(rLocal), (noRouting))

Request(300Ah,UFSStat, exchUFS, 0, 20, 1, 1, (none),(rLocal), (noRouting))

Request(300Bh,UFSFStat, exchUFS, 0, 8, 0, 1, (none),(rLocal), (noRouting))

Request(300Ch,UFSChange, exchUFS, 0, 22, 2, 0, (none),(rLocal), (noRouting))

Request(300Dh,UFSMount, exchUFS, 0, 10, 0, 0, (none),(rLocal), (noRouting))

Request(300Eh,UFSUMount, exchUFS, 0, 2, 0, 0, (none),(rLocal), (noRouting))

Request(300Fh,UFSSync, exchUFS, 0, 0, 0, 0, (none),(rLocal), (noRouting))

Request(3010h,RemoteMount,exchFilSys1, 0D0Eh, 2, 2, 0, (none),(rMasterFp), (noRouting))

Request(3011h,QueryRedirectStatus,exchKbd,00700h,0,0,1,(none),(rLocal), (noRouting))

Request(3012h,OpenTerminal,exchTPreq,0,4,0,1,(none),(rFileId), (noRouting))

Request(3013h,CloseTerminal,exchTPreq,0,4,0,0,(none),(rFileId), (noRouting))

Request(3014h,WhereTerminalBuffer,exchTPreq,0,4,0,1,(none),(rFileId), (noRouting))

Request(3015h,ReadTerminal,exchTPreq,0,6,0,2,(none),(rFileId), (noRouting))

Request(3016h,SetTerminal,exchTPreq,0,6,1,1,(none),(rFileId), (noRouting))

Request(3017h,SetTerminalOwner,exchTpReq,0,6,0,0, (none),(rFileId), (noRouting))

Request(3018h,RingOutTerminal,exchTpReq,0,4,0,0, (none),(rFileId), (noRouting))

Request(3019h,DrainTerminalOutput,exchTpReq,0,4,0,0, (none),(rFileId), (noRouting))

Request(301Ah,UFSUStat, exchUFS, 0, 2, 0, 1, (none),(rLocal), (noRouting))

Request(301Bh, UFSUTimes, exchUFS, 0, 20, 2, 0, (none),(rLocal), (noRouting))

Request(301Ch, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rRemote), (noRouting))

Request(301Dh, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rLocal), (noRouting))

Request(301Eh, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rLocal), (noRouting))

Request(301Fh, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rLocal), (noRouting))

Request(3020h, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rLocal), (noRouting))

Request(3021h, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rLocal), (noRouting))

Request(3022h, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rRemote), (noRouting))

Request(3023h, UFSDummy, exchUFS, 0, 0, 0, 0, (none),(rRemote), (noRouting))

Request(3024h,UpdateDCB,exchFilterPros,0807h,6,3,0, (None),(rLocal), (DevSpec SpecPW))

Request(3025h,ReadRemote,exchFilSys2,5,6,0,2,
		( fh p0 s0 lfa p1 c(2,28) ),(rHandle), (noRouting))

Request(3026h,WriteRemote,exchFilSys2,6,6,1,1,
		( fh p0 s0 lfa p1 c(2,28) ),(rHandle), (noRouting))

Request(3027h,CleanupRemoteExecution,exchKbd,0800h,0,0,0, (none),(rLocal), (noRouting))

Request(3028h,SetIoRedirectionMode,exchKbd,0900h,2,0,0, (none),(rLocal), (noRouting))

Request(3029h,UffTerminal,exchSrpAgent,0,6,2,3, (none),(rFileId), (noRouting))

Request(302Ah,WriteTerminal,exchSrpAgent,0,4,1,0,(none),(rFileId), (noRouting))

Request(302Bh,SizeWindow,exchSrpAgent,0,6,0,1, (none),(rFileId), (noRouting))

Request(302Ch,PlaceWindow,exchSrpAgent,0,6,0,1, (none),(rFileId), (noRouting))

Request(302Dh,CreateWindow,exchSrpAgent,0,6,0,2, (none),(rFileId), (noRouting))

Request(302Eh,DeleteWindow,exchSrpAgent,0,6,0,1, (none),(rFileId), (noRouting))

Request(302Fh,SelectWindow,exchSrpAgent,0,4,0,1, (none),(rFileId), (noRouting))

Request(3030h,GetWindowLayout,exchSrpAgent,0,4,0,1, (none),(rFileId), (noRouting))

Request(3031h,CatchWindowKeys,exchSrpAgent,0,4,0,2, (none),(rFileId), (noRouting))

Request(3032h,SetWindowText,exchSrpAgent,0,4,2,0, (none),(rFileId), (noRouting))
Request(3033h,MultibusRequest,exchResex,0D24h,6,0,0,( b(12) b(13) p(14) ),(rLocal), (noRouting))
Request(3034h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3035h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3036h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3037h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3038h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3039h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(303Ah,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(303Bh,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(303Ch,TpTerminate,exchTPreq,0,2,0,0,(none),(rLocal), (noRouting))
Request(303Dh,FlushLog,exchFilSys1,0900h,6,1,0,(p0 s0 ),(rMasterFp), (noRouting))
Request(303Eh,StartPT,exchSrpAgent,0,0,0,0,(none),(rLocal), (noRouting))
Request(303Fh,TapeRegisterSlave,exchTape,7,4,0,0,(b(12) b(13) b(14)),(rRemote), (noRouting))
Request(3040h,LocalOpenTape,exchTape,8,6,1,1,
		( p0 s0 b(12) b(13) b(14) w(16) p1 c(2,28) ),(rLocal), (noRouting))
Request(3041h,LocalPurgeTapeUser,exchTape,9,2,0,0,
		( w(12) ),(rLocal), (noRouting))
Request(3042h,TerminatePT,exchSrpAgent,2,0,0,0,(none),(rLocal), (noRouting))
Request(3043h,RPTia,ExchTia,0,6,1,0,(none),(rFileId), (noRouting))
Request(3044h,LocalConfigureSpooler, exchSplr,0000h,6,3,0,
		( b(12) p0 s0 p1 s1 p2 s2 b(13) b(14) ),(rLocal), (noRouting))
Request(3045h,LocalSpoolerPassword,exchSplr,0001h,6,2,0,
		( p0 s0 p1 s1 ),(rLocal), (noRouting))
Request(3046h,LocalResetSplr,exchSplr,0000,2,0,0, ( w(12)),(rLocal), (noRouting))
Request(3047h,TerminatePtEmulation,exchSrpAgent,0,2,0,0,(None),(rLocal), (noRouting))
Request(3048h,MegaFrameDisableCluster,exchFilSys1,0902h,6,0,0,
		( w(12) w(14) w(16)), (rMasterFp), (noRouting))
Request(3049h,HistRqCode,0,0,10,0,1,( w(12) w(14) w(16) w(20) w(18) w(24) w(22) w(26) ),(rLocal), (noRouting))
Request(304Ah,RebootMasterFp,0,0,4,0,0,(w(12) w(14)),(rRemote), (noRouting))
Request(304Bh,GetIobQueue,exchMassIO,0,2,0,2,
		( p0 s0 p1 c(2,24) ),(rFileId), (noRouting))
Request(304Ch,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(304Dh,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(304Eh,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(304Fh,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3050h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3051h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3052h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3053h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3054h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3055h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3056h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3057h,MultiAp,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(3058h,InternalChangeUserNumFs,'exchChgUsrN'0,0D13h,2,0,0,
		 ( w(12) ),(rLocal), (noRouting))
Request(3059h,Reserved,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(305Ah,Reserved,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(305Bh,Reserved,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(305Ch,Reserved,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(305Dh,Reserved,0,0,0,0,0,(none),(rLocal), (noRouting))
Request(305Eh,Reserved,0,0,0,0,0,(none),(rLocal), (noRouting))


;  User requests in levels 0C..0Fh should be added here

; Request 1 is included only as an example of a user request, and
; is commented out.  These UsrRequests are included only for
; compatibility with previous versions of workstation CTOS.
;
; (Note that exchanges 0 to 24 are reserved for CTOS processes.)
;

UsrRequestInit

'  UsrRequest(1,UserService,16,0001h,0,0,0,
'			( w(16) p0 s0 ),(rLocal), (noRouting))



;
; The list of request codes which the CTOS termination process	
; issues to quiet the process activities during subsystem	
; termination (invoked with Exit or Chain).  The requests	
; are generated with no arguments and with request numbers as	
; given to the macro.						
;

TerminationRequest(70)		; Request code for ResetKbd, to quiet keyboard process
TerminationRequest(71)		; Request code for ResetSysIn, to stop system input process
TerminationRequest(72)		; Reset Agent
TerminationRequest(96)		; Request code for PurgeISAM users
TerminationRequest(108)	; Request code for StopEm3270
TerminationRequest(153)        ; Request code for CloseAllCommLines
TerminationRequest(164)        ; Request code for ResetQueMgr
TerminationRequest(169)        ; Request code for PurgeX25User
TerminationRequest(195)	; Request code for PurgeTapeUser
TerminationRequest(197)        ; Request code for ResetSplr
TerminationRequest(233)        ; Request code for TerminateSNAUser.
TerminationRequest(239)        ; Request code for PurgeMailUser.
TerminationRequest(270)	; CtNetTermination
TerminationRequest(273)	; CMTermination
TerminationRequest(274)	; Filter Process Termination
TerminationRequest(2006h)	; Terminate SDLC
TerminationRequest(200Dh)	; Terminate BSNC
TerminationRequest(303Ch)	; Terminate any Open Read or Drain Rqs


EVEN
;  The list of request codes which the CTOS master workstation
;  agent or the CtNetServer issues on behalf of cluster workstation
;  when the master or the CtNetServer determines that a cluster
;  workstation is not communicating with it any more.
;

'	WsAbortRequest(0D002h)			; Reset users installed system service

	WsAbortRequest(96)
	WsAbortRequest(108)
	WsAbortRequest(148)
	WsAbortRequest(153)
	WsAbortRequest(195)
	WsAbortRequest(169)
	WsAbortRequest(229)
	WsAbortRequest(239)
	WsAbortRequest(251)
	WsAbortRequest(112)
	WsAbortRequest(2007H)
	WsAbortRequest(200EH)

;
;  The list of request codes which a MultiPartitioned CTOS     
;  issues on behalf of a system service to notify other system	
;  services its user number is changing.  These requests are	
;  issued when the system service does a ConvertToSys request.	
;  The system service's new user number is contained in a word  
;  at offset 4 in the request block.  The system service's      
;  previous user number is contained in a word at offset 12 in  
;  the request block.                                           
;

ChgUserNumRequest(218)		; Request code for ChangeUserNumQmg.
ChgUserNumRequest(259)		; ChangeUserNumMail

;  This macro must appear last in the file

final

End;
3048h,MegaFrameDisableCluster,exchFilSys1,0902h,6,0,0,
		( w(