;
; COPYRIGHT 1988 CONVERGENT TECHNOLOGIES, INC.
; ALL RIGHTS RESERVED
;
;
;This module is to be used by users who are creating Installable System Common ;procedures using the SystemCommonInstall procedure.  The steps in creating an ;installable system common are as follows:
;
;        1.  Decide on a procedure name for your new system common.  For
;            this example, we'll call it MySysComm.  Moreover, assume the
;            parameters are of the form: (pointer, returned pointer, word).
;
;        2.  Choose a system common number within the range available for
;            customer use.  There are two ranges.  Numbers in the range of
;            6000h  7FFFh are available for unrestricted customer use.
;            Numbers in the range 4000h  5FFFh are available for customer
;            use only by registering with Convergent Technologies Technical
;            Support, who keep a registry which ensures that no two
;            customers use the same number.
;            There are two ways to receive registered numbers.  If you are
;            connected to the CTMail network, send a Mail message to
;            REQUESTTS2 specifying your name, address, and how many numbers
;            you require.  Numbers will be registered in your company's name
;            and you will receive an EMail response to inform you of which
;            numbers were assigned to you.  Alternatively, you may call CT
;            Technical support at (800) 8588255 and explain that you wish
;            to register a System common number.  In a return call, you will
;            be informed of the numbers which have been registered in your
;            name.
;
;            For this example, we'll use 6000h.
;
;        3.  Write the code which will implement MySysComm.  This code should
;            have an initialization section which is responsible for
;            installing.  This code should make the following call:
;
;            call InstallSystemCommon(6000h, @MySysComm, @('pqw'), 3, ...);
;
;            where @MySysComm is the address of the public procedure which
;            implements the system common call, @('pqw') is a pointer to
;            the parameter string, and 3 is the length of the parameter
;            string.  For further information, see the CTOS Reference Manual.
;
;            This notifies CTOS of the location of the code which will
;            implement the 1808th system common procedure.  The initialization
;            code should then call ConvertToSys and wait on an exchange set up
;            for deinstallation.
;
;        4.  Create a command called InstallMySysComm to install the server.
;
;For an application program to actually make use of this new installed system
;common procedure, the following steps should be taken:
;
;        1.  In the source of the application make a call to MySysComm, which
;            should be declared EXTERNAL.
;
;        2.  Edit this file by adding a macro call of the following form:
;
'               OsSubLab(6000, MySysComm)
;                ^
;                \
;                |
;                |
;             Start in column 1
;
;            This macro call will cause an ABSOLUTE PUBLIC symbol of MySysComm
;            to be created.  Its value will be resolved at load time to the
;            correct address of MySysComm.
;
;
;        3.  Link the application program modules with the module created by
;            assembling this module.
;
;        4.  Run InstallMySysComm
;
;        5.  Run your application program.
;
;



STACK SEGMENT STACK 'STACK'        ; default stack so programs won't crash 
    DB 512 DUP (?)
STACK ENDS

$include([Sys]<Sys>ossub.mdf)



;***************************************************************
;  EXAMPLE                                                     *
;                                                              *
'         OsSubLab(262, SystemCommonCheck)                 *
;                                                              *
;                                                              *
;***************************************************************
;
; ***** Put OsSubLab macros below this line





; The following macro is for backwards compatability with object
; modules compiled using old names for CTOS procedures.  The
; syntax is:
;
'        Same(SysCommonName, Alias)
;
; You will not need to worry about this unless you are replacing
; an existing system common procedure which was known by two
; names.
;
;***************************************************************
;  EXAMPLE                                                     *
;                                                              *
'        Same(SystemCommonCheck, GetUserNum)             *
;                                                              *
;                                                              *
;***************************************************************
;
; **** Put Same macros below this line


END
ent MyFunction1 and MyFunction2.
;            This code should have an ini